@@ -1,6 +1,6 @@
 package SQLite::Work;
-BEGIN {
-  $SQLite::Work::VERSION = '0.11';
+{
+  $SQLite::Work::VERSION = '0.12';
 }
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ SQLite::Work - report on and update an SQLite database.
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -362,6 +362,7 @@ sub do_disconnect {
 	show=>\@show,
 	distinct=>0,
 	headers=>\@headers,
+	header_start=>1,
 	groups=>\@groups,
 	limit=>$limit,
 	page=>$page,
@@ -445,6 +446,10 @@ This version can likewise use multiple columns in its display parts.
 
 The same format is used for L<groups> and L<row_template>.
 
+=item header_start
+
+At what level the headers should start.  Default is 1 (H1).
+
 =item layout
 
 The layout of the report.  This determines both how rows are grouped,
@@ -606,6 +611,7 @@ sub do_report {
 	page=>1,
 	table2=>'',
 	headers=>[],
+	header_start=>1,
 	groups=>[],
 	sort_by=>[],
 	sort_reversed=>{},
@@ -698,6 +704,7 @@ sub do_multi_page_report {
 	page=>1,
 	table2=>'',
 	headers=>[],
+	header_start=>1,
 	groups=>[],
 	sort_by=>[],
 	sort_reversed=>{},
@@ -865,6 +872,7 @@ sub do_multi_page_report {
 	sort_reversed=>\%sort_reversed,
 	show=>\@show,
 	headers=>\@headers,
+	header_start=>1,
 	groups=>\@groups,
 	limit=>$limit,
 	page=>$page,
@@ -914,6 +922,7 @@ sub do_split_report {
 	page=>1,
 	table2=>'',
 	headers=>[],
+	header_start=>1,
 	groups=>[],
 	sort_by=>[],
 	sort_reversed=>{},
@@ -1555,21 +1564,12 @@ sub make_selections {
 	limit=>0,
 	page=>1,
 	table2=>'',
-	headers=>[],
-	groups=>[],
 	sort_by=>[],
 	sort_reversed=>{},
 	not_where=>{},
 	where=>{},
 	show=>[],
 	distinct=>0,
-	layout=>'table',
-	row_template=>'',
-	outfile=>'',
-	report_style=>'full',
-	title=>'',
-	prev_file=>'',
-	next_file=>'',
 	@_
     );
     my $table = $args{table};
@@ -2128,6 +2128,7 @@ $my report = $self->format_report(
 	force_show_cols=>\%force_show_cols,
 	sort_by=>\@sort_by,
 	headers=>\@headers,
+	header_start=>1,
 	table2=>$table2,
 	layout=>'table',
 	row_template=>$row_template,
@@ -2156,6 +2157,7 @@ sub format_report {
     my @columns = @{$args{columns}};
     my @sort_by = @{$args{sort_by}};
     my @headers = @{$args{headers}};
+    my $header_start = $args{header_start} || 1;
     my @groups = @{$args{groups}};
     my %force_show_cols = %{$args{force_show_cols}};
     my $command = $args{command};
@@ -2310,7 +2312,7 @@ sub format_report {
 		    }
 		    # only make a header if it has content
 		    push @out, sprintf("<h%d>%s</h%d>\n",
-				       $hi + 1, $hval, $hi + 1)
+				       $hi + $header_start, $hval, $hi + $header_start)
 					if $hval;
 		    # and group content, if there is any
 		    push @out, "<p>$gval</p>\n", if $gval;
@@ -2657,4 +2659,4 @@ under the same terms as Perl itself.
 =cut
 
 1; # End of SQLite::Work
-__END__
\ No newline at end of file
+__END__
