@@ -1,6 +1,6 @@
 package SQLite::Work::CGI;
-BEGIN {
-  $SQLite::Work::CGI::VERSION = '0.11';
+{
+  $SQLite::Work::CGI::VERSION = '0.12';
 }
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ SQLite::Work::CGI - Report and update a SQLite database using CGI
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -963,6 +963,14 @@ sub make_buttons {
 <input type="hidden" name="Table" value="$table"/>
 <input type="hidden" name="Table2" value="$table2"/>
 <input type="submit" value="$command $table again"/>
+EOT
+    if ($command eq 'Edit')
+    {
+	push @out,<<EOT;
+<input type="submit" name="Add_Row" value="Add Row"/>
+EOT
+    }
+    push @out,<<EOT;
 </form></td>
 EOT
 
@@ -1727,4 +1735,4 @@ under the same terms as Perl itself.
 =cut
 
 1; # End of SQLite::Work::CGI
-__END__
\ No newline at end of file
+__END__
